{% load get_by_id %} {% load i18n %}

### History

{% blocktrans with page_number=history.number num_pages=history.paginator.num_pages %}Page {{ page_number }} of {{ num_pages }}.{% endblocktrans %}
{% include "boards/pagination.html" with items=history %}

{% trans "Date" %} | {% trans "State" %} | {% trans "Code" %} | {% trans "Response" %} | {% trans "NAMELOOKUP" %} | {% trans "CONNECT" %} | {% trans "PRETRANSFER" %} | {% trans "STARTTRANSFER" %} | {% trans "REDIRECT TIME" %} | {% trans "SIZE DOWNLOAD" %} | {% trans "SPEED DOWNLOAD" %} | {% trans "REDIRECT COUNT" %} | {% trans "CONNECTS COUNT" %} | {% trans "ARP" %} | {% trans "AGENT" %}
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
{% for item in history %}
{{ item.created|date:"Y-m-d H:i" }} | {% if item.response_state == 1 %}{% trans "OK" %}{% elif item.response_state == 2 %}{% trans "Performance" %}{% elif item.response_state == 3 %}{% trans "Serice is working incorrectly" %}{% elif item.response_state == 4 %}{% trans "Wordchecks errors" %}{% else %}{% trans "Agent fail" %}{% endif %} | {{ item.response_code }} | {{ item.response_time|floatformat:2 }} | {{ item.namelookup_time|floatformat:2 }} | {{ item.connect_time|floatformat:2 }} | {{ item.pretransfer_time|floatformat:2 }} | {{ item.starttransfer_time|floatformat:2 }} | {{ item.redirect_time|floatformat:2 }} | {% if item.size_download %}{{ item.size_download }} B{% endif %} | {% if item.speed_download %}{{ item.speed_download }} B/s{% endif %} | {% if item.redirect_count != None %}{{ item.redirect_count }}{% endif %} | {{ item.num_connects|default:"" }} | {{ params|get_by_id:item.request_params_id }} | {{ agents|get_by_id:item.agent_id }}
{% endfor %}

{% include "boards/pagination.html" with items=history %}